/*
  Copyright Jesús Rubio <jesusprubio@gmail.com>

  This code may only be used under the MIT license found at
  https://opensource.org/licenses/MIT.
*/

'use strict';

// https://developer.shodan.io/api/exploits/rest

const utils = require('./utils');

// Optional parameters for each function.
const optsExpected = {
  search: ['facets', 'page'],
  count: ['facets'],
};

async function req(endpoint, query, key, opts = {}) {
  if (!query) {
    throw new Error(utils.buildErrorRequired('query'));
  }

  const params = utils.buildParams(optsExpected[endpoint], opts);
  params.query = query;
  params.key = key;

  return utils.request('exploits', `/api/${endpoint}`, {
    params,
    timeout: opts.timeout
  });
}

module.exports.search = async (query, key, opts = {}) =>
  req('search', query, key, opts);

module.exports.count = async (query, key, opts = {}) =>
  req('count', query, key, opts);
